@@ -1,5 +1,5 @@
 package PDL::Role::RowNameable;
-$PDL::Role::RowNameable::VERSION = '0.003';
+$PDL::Role::RowNameable::VERSION = '0.006001';
 use strict;
 use warnings;
 
@@ -19,15 +19,25 @@ PDL::Role::RowNameable
 
 =head1 VERSION
 
-version 0.003
+version 0.006001
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Zakariyya Mughal <zmughal@cpan.org>
 
+=item *
+
+Stephan Loyd <sloyd@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Zakariyya Mughal.
+This software is copyright (c) 2014, 2019-2022 by Zakariyya Mughal, Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
